"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.continueWith = void 0;
const rxjs_1 = require("rxjs");
const NO_VAL = {};
const continueWith = (mapper) => (source$) => new rxjs_1.Observable((observer) => {
    let latestValue = NO_VAL;
    const subscription = new rxjs_1.Subscription();
    subscription.add(source$.subscribe({
        complete: () => {
            if (latestValue === NO_VAL) {
                observer.complete();
            }
            else {
                const nextObservable$ = rxjs_1.from(mapper(latestValue));
                subscription.add(nextObservable$.subscribe(observer));
            }
        },
        error: (e) => {
            observer.error(e);
        },
        next: (val) => {
            observer.next((latestValue = val));
        },
    }));
    return subscription;
});
exports.continueWith = continueWith;
//# sourceMappingURL=continueWith.js.map